Name:           cppcheck
Version:        2.15.0
Release:        %mkrel 1
Summary:        Static analysis tool for C/C++
License:        GPLv3+
Group:          Development/C++
Url:            https://cppcheck.sourceforge.io/
Source:         https://github.com/danmar/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
# Fix location of translations
Patch1:         cppcheck-2.11-translations.patch

BuildRequires:  cmake
BuildRequires:  docbook-style-xsl
BuildRequires:  libxslt-proc
# re-enable pcre support once an upstream port to pcre2
# https://trac.cppcheck.net/ticket/10610
#BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(tinyxml2)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(setuptools-scm)
BuildRequires:  cmake(Qt6Charts)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Help)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Widgets)

%description
This program tries to detect bugs that your C/C++ compiler does not
find. Cppcheck is versatile. You can check non-standard code that includes
various compiler extensions, inline assembly code, etc. One of its goals
is no false positives.

%package gui
Summary:        Qt graphical user interface for cppcheck
Group:          Development/C++
Requires:       %{name} >= %{version}-%{release}

%description gui
This package contains the graphical user interface for cppcheck
based on Qt6.

%prep
%autosetup -p1
# Make sure bundled tinyxml2 is not used
rm -r externals/tinyxml2

%build
# re-enable pcre support once an upstream port to pcre2 (HAVE_RULES=ON)
%cmake -DHAVE_RULES=OFF \
       -DBUILD_GUI=ON \
       -DUSE_QT6=ON \
       -DWITH_QCHART=ON \
       -DFILESDIR=%{_datadir}/%{name} \
       -DUSE_BUNDLED_TINYXML2=OFF
%cmake_build

pushd htmlreport
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_wheel
popd

# this command line is documented inside cppcheck.1.xml
pushd man
xsltproc --nonet --param man.charmap.use.subset "0" \
   --param make.year.ranges "1" --param make.single.year.ranges "1" \
   /usr/share/sgml/docbook/xsl-stylesheets/manpages/docbook.xsl \
   cppcheck.1.xml
popd

%check
%ifnarch aarch64
make -C build test
%endif
true

%install
%cmake_install

pushd htmlreport
%pyproject_install
# We only want the binary.
rm -rf %{buildroot}%{python3_sitelib}/cppcheck*
popd

install -D -m 0644 man/cppcheck.1 %{buildroot}%{_mandir}/man1/cppcheck.1

%files
%doc AUTHORS readme.txt
%license COPYING
%{_bindir}/cppcheck
%{_bindir}/cppcheck-htmlreport
%{_datadir}/cppcheck/
%{_mandir}/man1/cppcheck.1*

%files gui
%doc AUTHORS readme.txt
%license COPYING
%{_bindir}/cppcheck-gui
%{_datadir}/applications/cppcheck-gui.desktop
%{_iconsdir}/hicolor/*/apps/cppcheck-gui.png
%{_iconsdir}/hicolor/scalable/apps/cppcheck-gui.svg


%changelog
* Sat Sep 07 2024 daviddavid <daviddavid> 2.15.0-1.mga10
+ Revision: 2093451
- new version: 2.15.0

* Wed Feb 14 2024 daviddavid <daviddavid> 2.13.0-1.mga10
+ Revision: 2041166
- new version: 2.13.0

* Tue Feb 13 2024 daviddavid <daviddavid> 2.12.1-3.mga10
+ Revision: 2040961
- rebuild for new tinyxml2 10.0.0

* Wed Dec 20 2023 daviddavid <daviddavid> 2.12.1-2.mga10
+ Revision: 2020021
- rebuild for py3.12

* Sat Oct 28 2023 daviddavid <daviddavid> 2.12.1-1.mga10
+ Revision: 2002241
- new version: 2.12.1
- switch to Qt6
- disable rules support and remove build dependency on old/obsolete pcre1

* Sat Jun 24 2023 daviddavid <daviddavid> 2.11-1.mga9
+ Revision: 1962945
- new version: 2.11

* Fri Jun 23 2023 daviddavid <daviddavid> 2.9-3.mga9
+ Revision: 1962885
- enable the Qt graphical user interface
- fix cppcheck data path
- no more needed to install manually cfg files
- update Url

* Thu Oct 20 2022 papoteur <papoteur> 2.9-2.mga9
+ Revision: 1897972
- Rebuild for tinyxml2 9.0.0

* Tue Sep 13 2022 luigiwalser <luigiwalser> 2.9-1.mga9
+ Revision: 1887913
- 2.9

* Mon Aug 08 2022 mrambo3501 <mrambo3501> 2.7.4-3.mga9
+ Revision: 1876129
- use Python's bundled distutils

* Sun Aug 07 2022 mrambo3501 <mrambo3501> 2.7.4-2.mga9
+ Revision: 1875994
- fix filelists

* Tue Mar 29 2022 luigiwalser <luigiwalser> 2.7.4-1.mga9
+ Revision: 1831304
- 2.7.4
- remove patches (issues fixed upstream)

* Sat Mar 19 2022 umeabot <umeabot> 2.7-2.mga9
+ Revision: 1799671
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 luigiwalser <luigiwalser> 2.7-1.mga9
+ Revision: 1782635
- 2.7
- update patches from fedora

* Fri Jan 14 2022 mrambo3501 <mrambo3501> 2.6-1.mga9
+ Revision: 1768361
- version 2.6
- delete patch3 applied upstream

* Thu Aug 05 2021 luigiwalser <luigiwalser> 2.5-1.mga9
+ Revision: 1739364
- 2.5
- replace test disablement patch with updated one from fedora
- add patch from fedora to fix loading English translations

* Thu Jul 01 2021 joequant <joequant> 2.4-1.mga9
+ Revision: 1734420
- update to 2.4 cppcheck

* Wed Dec 30 2020 luigiwalser <luigiwalser> 2.3-1.mga8
+ Revision: 1665847
- 2.3
- remove patches 4 and 5 (fixed upstream)
- use cmake option to build against system tinyxml2

* Tue Nov 24 2020 akien <akien> 2.2-2.mga8
+ Revision: 1648911
- Install cppcheck-htmlreport

* Wed Oct 07 2020 shlomif <shlomif> 2.2-1.mga8
+ Revision: 1632541
- New version 2.2

* Fri Aug 21 2020 joequant <joequant> 2.1-2.mga8
+ Revision: 1617555
- fix cmake

* Thu Jun 25 2020 shlomif <shlomif> 2.1-1.mga8
+ Revision: 1599274
- New version 2.1

* Thu May 21 2020 shlomif <shlomif> 2.0-1.mga8
+ Revision: 1586612
- New version 2.0

* Tue Feb 18 2020 umeabot <umeabot> 1.90-2.mga8
+ Revision: 1541396
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Dec 26 2019 shlomif <shlomif> 1.90-1.mga8
+ Revision: 1470154
- New version 1.90

* Sun Jul 07 2019 shlomif <shlomif> 1.88-1.mga8
+ Revision: 1419219
- New version 1.88

* Sun Feb 03 2019 pterjan <pterjan> 1.86-2.mga7
+ Revision: 1362955
- Drop char sign patch, seems fixed upstream and patch now breaks the tests

* Mon Jan 28 2019 shlomif <shlomif> 1.86-1.mga7
+ Revision: 1361595
- skip tests on failing archs
- New version 1.86
- New version 1.85
+ wally <wally>
- build with pcre

* Thu Oct 04 2018 wally <wally> 1.84-3.mga7
+ Revision: 1317537
- add patch based on one from Debian to build with system tinyxml2
- add patch to fix linking
- add Debian patch to fix check on aarch64

* Sun Sep 23 2018 umeabot <umeabot> 1.84-2.mga7
+ Revision: 1296846
- Mageia 7 Mass Rebuild

* Mon Aug 20 2018 shlomif <shlomif> 1.84-1.mga7
+ Revision: 1253079
- New version 1.84

* Tue May 15 2018 akien <akien> 1.83-2.mga7
+ Revision: 1229730
- Rebuild for tinyxml 6.2.0

* Mon Apr 16 2018 shlomif <shlomif> 1.83-1.mga7
+ Revision: 1219458
- New version 1.83

* Sat Feb 24 2018 shlomif <shlomif> 1.82-1.mga7
+ Revision: 1204857
- New version 1.82

* Fri Oct 20 2017 zezinho <zezinho> 1.81-1.mga7
+ Revision: 1172931
- new version

* Tue Sep 19 2017 shlomif <shlomif> 1.80-1.mga7
+ Revision: 1155445
- New version 1.80

* Tue Aug 08 2017 daviddavid <daviddavid> 1.79-2.mga7
+ Revision: 1138907
- rebuild for new tinyxml2 5.0.1

* Mon Jul 17 2017 shlomif <shlomif> 1.79-1.mga7
+ Revision: 1123939
- New version 1.79

* Sun Jan 15 2017 shlomif <shlomif> 1.77-1.mga6
+ Revision: 1081911
- New version 1.77.

* Thu May 12 2016 daviddavid <daviddavid> 1.72-2.mga6
+ Revision: 1014019
- replace some macros thus fixing build

* Wed Feb 10 2016 shlomif <shlomif> 1.72-1.mga6
+ Revision: 953310
- New version 1.72

* Mon Jan 04 2016 shlomif <shlomif> 1.71-2.mga6
+ Revision: 919548
- Skip failing tests
- New version 1.71

* Sat Oct 24 2015 shlomif <shlomif> 1.70-1.mga6
+ Revision: 894992
- New version 1.70

* Thu Jul 30 2015 shlomif <shlomif> 1.69-2.mga6
+ Revision: 859060
- Apply some fixes from the Fedora SPEC + Fix MGA#16471.
- Missing CFG files so it doesn't run properly.

* Sat Jun 20 2015 shlomif <shlomif> 1.69-1.mga6
+ Revision: 835823
- New version 1.69

* Wed Oct 15 2014 umeabot <umeabot> 1.65-3.mga5
+ Revision: 739066
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.65-2.mga5
+ Revision: 678567
- Mageia 5 Mass Rebuild

* Wed May 21 2014 shlomif <shlomif> 1.65-1.mga5
+ Revision: 624657
- New version 1.65

* Fri Feb 14 2014 kharec <kharec> 1.63-1.mga5
+ Revision: 591384
- new version 1.63

* Sat Oct 19 2013 umeabot <umeabot> 1.61-2.mga4
+ Revision: 531533
- Mageia 4 Mass Rebuild

* Mon Aug 05 2013 sander85 <sander85> 1.61-1.mga4
+ Revision: 463846
- New version: 1.61

* Wed Jun 05 2013 kharec <kharec> 1.60.1-1.mga4
+ Revision: 437563
- update to 1.60.1

* Thu May 23 2013 kharec <kharec> 1.59-1.mga4
+ Revision: 425109
- update to 1.59

* Mon Feb 25 2013 kharec <kharec> 1.58-1.mga3
+ Revision: 400313
- Fix rpm group
- new version 1.58

* Fri Jan 11 2013 umeabot <umeabot> 1.57-2.mga3
+ Revision: 348241
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 1.57-1.mga3
+ Revision: 325241
- new version 1.57
- clean .spec

* Mon Sep 03 2012 shlomif <shlomif> 1.56-2.mga3
+ Revision: 287642
- fix description

* Mon Sep 03 2012 kharec <kharec> 1.56-1.mga3
+ Revision: 287622
- new version 1.56

* Thu Jul 05 2012 kharec <kharec> 1.55-1.mga3
+ Revision: 267970
- 1.55

* Mon May 28 2012 kharec <kharec> 1.54-1.mga3
+ Revision: 247930
- Update to 1.54 (many improves and bugfix)

* Tue Feb 21 2012 kharec <kharec> 1.53-1.mga2
+ Revision: 211581
- New version 1.53

* Mon Dec 12 2011 kharec <kharec> 1.52-1.mga2
+ Revision: 180843
- New version 1.52

* Sun Nov 20 2011 kharec <kharec> 1.51-1.mga2
+ Revision: 170013
- new version 1.51

* Sun Nov 20 2011 kharec <kharec> 1.47-1.mga2
+ Revision: 169901
- imported package cppcheck

